cache

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cache

type Cache interface {
	// Vaults returns the list of stateful sets for which Vault information is cached.
	Vaults() []string
	// VaultInfoFor retrieves the Vault information for the specified instance.
	VaultInfoFor(name string) *types.VaultInfo
	// SetVaultInfoFor sets the Vault information for the specified instance.
	SetVaultInfoFor(name string, info *types.VaultInfo)
	// Sync synchronizes the cache with the external source, if applicable.
	Sync()
	// SetMember sets the member status for the cache, if applicable.
	SetMember(members map[string]string) bool
	// IsK8sPast123 return whether kubernetes version is past 1.32 or not
	IsK8sPast123() bool
}

Cache defines the interface for managing Vault information cache.

func NewSimple

func NewSimple(past132 bool) Cache

NewSimple creates a new simple cache instance.

type RunnableCache

type RunnableCache interface {
	Cache
	manager.Runnable
	// SetupWithManager sets up the cache with the provided manager for running as a controller-runtime Runnable.
	SetupWithManager(mgr ctrl.Manager) error
}

RunnableCache extends the Cache interface with additional methods for running as a controller-runtime Runnable.

func NewK8s added in v0.2.0

func NewK8s(reader client.Reader, past132 bool) (RunnableCache, error)

NewK8s creates a new Kubernetes cache instance.

Jump to